searchData={"items":[{"type":"module","title":"KinoLiveAudio","doc":"A Kino designed to record a raw audio stream (no client-side encoding) and emit events.\n\nWhen you consume the events, you can directly convert the audio to an `Nx` tensor.\n\nYou may specify the sample rate of the audio and the frequency that events should be emmitted\nby specifying how many samples should accumulate before sending to the server.\n\nRefer to the sample [Livebook](notebooks/vad.livemd) for usage.","ref":"KinoLiveAudio.html"},{"type":"function","title":"KinoLiveAudio.new/1","doc":"Creates a new `KinoLiveAudio`","ref":"KinoLiveAudio.html#new/1"},{"type":"function","title":"Options - KinoLiveAudio.new/1","doc":"* `:chunk_size` - Wait for this many samples before sending. Will send exactly this amount to the\n    emmited event. Must be a positive integer. Defaults to 16_000.\n* `:sample_rate` - The sample rate of the audio stream. Defaults to 16_000.\n* `:unit` - The unit for the `:chunk_size` option. Can be any of the following:\n  * `:samples` - Directly passes the `:chunk_size` parameter\n  * `:s` - Seconds of audio before sending, according to the sample rate\n  * `:ms` - Miliseconds of audio before sending, according to the sample rate\n  * `:mu` - Microseconds of audio before sending, according to the sample rate","ref":"KinoLiveAudio.html#new/1-options"},{"type":"extras","title":"Nx VAD","doc":"<!-- livebook:{\"app_settings\":{\"access_type\":\"public\",\"output_type\":\"rich\",\"show_source\":true,\"slug\":\"vad\"}} -->\n\n# Nx VAD\n\n```elixir\nMix.install([\n  {:ortex, \"~> 0.1.9\"},\n  {:kino_vega_lite, \"~> 0.1.10\"},\n  {:kino_live_audio, \"~> 0.1\"}\n])\n```","ref":"vad.html"},{"type":"extras","title":"Setup Model & Plot - Nx VAD","doc":"```elixir\nsample_rate = 16_000\nmodel = Ortex.load(\"/Users/andres/Downloads/Silero_VAD.onnx\")\n\nchart =\n  VegaLite.new(title: \"Voice-Activated Detection\", width: 800, height: 400)\n  |> VegaLite.mark(:line)\n  |> VegaLite.encode_field(:x, \"x\",\n    type: :quantitative,\n    title: \"Time\",\n    axis: [ticks: false, domain: false, grid: false, labels: false]\n  )\n  |> VegaLite.encode_field(:y, \"y\",\n    type: :quantitative,\n    title: \"Voice\",\n    scale: [domain_max: 1, domain_min: 0]\n  )\n  |> Kino.VegaLite.new()\n```\n\n```elixir\nliveAudio = KinoLiveAudio.new(chunk_size: 30, unit: :ms, sample_rate: sample_rate)\n```\n\n```elixir\nliveAudio\n|> Kino.Control.stream()\n|> Kino.listen(fn\n  %{event: :audio_chunk, chunk: data} ->\n    input = Nx.tensor(data) |> Nx.stack()\n    sr = Nx.tensor(sample_rate, type: :s64)\n    seconds_sampled = Nx.shape(input) |> elem(0)\n    h = Nx.broadcast(0.0, {2, seconds_sampled, 64})\n    c = Nx.broadcast(0.0, {2, seconds_sampled, 64})\n    {output, _hn, _cn} = Ortex.run(model, {input, sr, h, c})\n    [output] = Nx.to_list(output |> Nx.flatten())\n    row = %{x: :os.system_time(), y: output}\n    Kino.VegaLite.push(chart, row, window: 1000)\nend)\n```","ref":"vad.html#setup-model-plot"}],"content_type":"text/markdown"}